@@ -51,10 +51,22 @@ def main(*args):
                         number of contacts.")
     parser.add_argument("--chrNames", type=str, nargs='*', default=[],
                         help="Only compute the SCC scores on this subset of\
-                        chromosomes whose names are provided")
+                        chromosomes whose names are provided. The output SCC\
+                        scores will be ordered as the input chromosome names\
+                        here")
+    parser.add_argument("--excludeChr", type=str, nargs='*', default=['M'],
+                        help="Exclude chromosomes from the SCC score calculations.\
+                        Mitochondrial chromosomes named \"M\" are excluded by\
+                        default. The output SCC scores will be ordered as the\
+                        chromosomes in the input Cooler files by removing those\
+                        chromosomes provided here")
 
     args = parser.parse_args()
 
+    assert not (args.excludeChr != ['M'] and len(args.chrNames) > 0), f"""
+        Please use --chrNames OR --excludeChr arguments but not both.
+        """
+
     header = "#"+" ".join(sys.argv)+"\n"
 
     # Check if current script is under revision control
@@ -79,11 +91,18 @@ def main(*args):
     h = args.h
     dBPMax = args.dBPMax
     bDownSample = args.bDownSample
-    chrNames = np.array(args.chrNames, dtype=str)
+    chrNames = args.chrNames
+    excludeChr = set(args.excludeChr)
+
+    if len(excludeChr) != len(args.excludeChr):
+        warnings.warn(f"""
+            Duplicate excludeChr found. Please remove them in --excludeChr""")
 
     cool1, binSize1 = readMcool(fmcool1, binSize)
     cool2, binSize2 = readMcool(fmcool2, binSize)
 
-    scc = hicrepSCC(cool1, cool2, h, dBPMax, bDownSample, chrNames)
+    scc = hicrepSCC(cool1, cool2, h, dBPMax, bDownSample,
+                    chrNames if len(chrNames) > 0 else None,
+                    excludeChr if len(excludeChr) > 0 else None)
 
     np.savetxt(fout, scc, "%30.15e", header=header)
